@@ -23,10 +23,12 @@ from pcs.common.types import (
 
 ModifierValueType = Union[None, bool, str]
 
+_FUTURE_OPTION_STR = "future"
+FUTURE_OPTION = f"--{_FUTURE_OPTION_STR}"
 _OUTPUT_FORMAT_OPTION_STR = "output-format"
 _OUTPUT_FORMAT_OPTION = f"--{_OUTPUT_FORMAT_OPTION_STR}"
 OUTPUT_FORMAT_VALUE_TEXT = "text"
-_OUTPUT_FORMAT_VALUES = frozenset((OUTPUT_FORMAT_VALUE_TEXT, "cmd", "json"))
+OUTPUT_FORMAT_VALUES = frozenset((OUTPUT_FORMAT_VALUE_TEXT, "cmd", "json"))
 
 ARG_TYPE_DELIMITER = "%"
 
@@ -53,6 +55,7 @@ PCS_LONG_OPTIONS = [
     "off",
     "request-timeout=",
     "brief",
+    _FUTURE_OPTION_STR,
     # resource (safe-)disable
     "safe",
     "no-strict",
@@ -336,7 +339,9 @@ def group_by_keywords(
     return get_completed_groups()
 
 
-def parse_typed_arg(arg, allowed_types, default_type):
+def parse_typed_arg(
+    arg: str, allowed_types: StringSequence, default_type: str
+) -> tuple[str, str]:
     """
     Get (type, value) from a typed commandline argument.
 
@@ -501,6 +506,7 @@ class InputModifiers:
                 "--expired": "--expired" in options,
                 "--force": "--force" in options,
                 "--full": "--full" in options,
+                FUTURE_OPTION: FUTURE_OPTION in options,
                 # TODO remove
                 # used only in deprecated 'pcs resource|stonith show'
                 "--groups": "--groups" in options,
@@ -643,7 +649,7 @@ class InputModifiers:
         raise AssertionError(f"Non existing default value for '{option}'")
 
     def get_output_format(
-        self, supported_formats: Set[str] = _OUTPUT_FORMAT_VALUES
+        self, supported_formats: Set[str] = OUTPUT_FORMAT_VALUES
     ) -> str:
         output_format = self.get(_OUTPUT_FORMAT_OPTION)
         if output_format in supported_formats:
