@@ -5,17 +5,16 @@ from .order import constraint_plain as order_plain
 from .ticket import constraint_plain as ticket_plain
 
 
-def constraint_to_str(constraint_type, constraint_info, with_id=True):
+def constraint_to_str(constraint_type, constraint_info):
     """
     dict constraint_info  see constraint in pcs/lib/exchange_formats.md
-    bool with_id have to show id with options_dict
     """
     if "resource_sets" in constraint_info:
-        return constraint_with_sets(constraint_info, with_id)
-    return constraint_plain(constraint_type, constraint_info, with_id)
+        return constraint_with_sets(constraint_info)
+    return _constraint_plain(constraint_type, constraint_info)
 
 
-def constraint_plain(constraint_type, options_dict, with_id=False):
+def _constraint_plain(constraint_type, options_dict):
     """return console shape for any constraint_type of plain constraint"""
     type_report_map = {
         "rsc_colocation": colocation_plain,
@@ -24,5 +23,5 @@ def constraint_plain(constraint_type, options_dict, with_id=False):
     }
 
     if constraint_type not in type_report_map:
-        return constraint_plain_default(constraint_type, options_dict, with_id)
-    return type_report_map[constraint_type](options_dict, with_id)
+        return constraint_plain_default(constraint_type, options_dict)
+    return type_report_map[constraint_type](options_dict)
