@@ -1,18 +1,25 @@
-from collections import namedtuple
-from enum import Enum
 import threading
+import uuid
+from collections import namedtuple
 from typing import (
     MutableSet,
     Optional,
     TypeVar,
+    Union,
 )
 
 from lxml import etree
+from lxml.etree import _Element
 
+from pcs.common.types import StringCollection
 
 T = TypeVar("T", bound=type)
 
 
+def bin_to_str(binary: bytes) -> str:
+    return "".join(map(chr, binary))
+
+
 def get_all_subclasses(cls: T) -> MutableSet[T]:
     subclasses = set(cls.__subclasses__())
     return subclasses.union(
@@ -20,6 +27,14 @@ def get_all_subclasses(cls: T) -> MutableSet[T]:
     )
 
 
+def get_unique_uuid(already_used: StringCollection) -> str:
+    is_duplicate = True
+    while is_duplicate:
+        candidate = str(uuid.uuid4())
+        is_duplicate = candidate in already_used
+    return candidate
+
+
 def run_parallel(worker, data_list):
     thread_list = []
     for args, kwargs in data_list:
@@ -36,13 +51,13 @@ def format_environment_error(e):
     return format_os_error(e)
 
 
-def format_os_error(e):
+def format_os_error(e: OSError):
     if e.filename:
         return "{0}: '{1}'".format(e.strerror, e.filename)
     return e.strerror
 
 
-def xml_fromstring(xml):
+def xml_fromstring(xml: str) -> _Element:
     # If the xml contains encoding declaration such as:
     # <?xml version="1.0" encoding="UTF-8"?>
     # we get an exception in python3:
@@ -57,11 +72,35 @@ def xml_fromstring(xml):
     )
 
 
-class AutoNameEnum(str, Enum):
-    def _generate_next_value_(name, start, count, last_values):
-        # pylint: disable=no-self-argument
-        del start, count, last_values
-        return name
+def timeout_to_seconds(timeout: Union[int, str]) -> Optional[int]:
+    """
+    Transform pacemaker style timeout to number of seconds. If `timeout` is not
+    a valid timeout, `None` is returned.
+
+    timeout -- timeout string
+    """
+    try:
+        candidate = int(timeout)
+        if candidate >= 0:
+            return candidate
+        return None
+    except ValueError:
+        pass
+    # Now we know the timeout is not an integer nor an integer string.
+    # Let's make sure mypy knows the timeout is a string as well.
+    timeout = str(timeout)
+    suffix_multiplier = {
+        "s": 1,
+        "sec": 1,
+        "m": 60,
+        "min": 60,
+        "h": 3600,
+        "hr": 3600,
+    }
+    for suffix, multiplier in suffix_multiplier.items():
+        if timeout.endswith(suffix) and timeout[: -len(suffix)].isdigit():
+            return int(timeout[: -len(suffix)]) * multiplier
+    return None
 
 
 class Version(namedtuple("Version", ["major", "minor", "revision"])):
