@@ -384,7 +384,10 @@ def simulate_cib_xml(runner, cib_xml):
     string cib_xml -- CIB XML to simulate
     """
     try:
-        with tools.get_tmp_file() as new_cib_file, tools.get_tmp_file() as transitions_file:
+        with (
+            tools.get_tmp_file(None) as new_cib_file,
+            tools.get_tmp_file(None) as transitions_file,
+        ):
             cmd = [
                 __exec("crm_simulate"),
                 "--simulate",
@@ -735,7 +738,7 @@ def _run_fence_history_command(runner, command, node=None):
 
 
 def has_rule_in_effect_status_tool() -> bool:
-    return os.path.isfile(__exec("crm_rule"))
+    return os.path.isfile(settings.crm_rule)
 
 
 def get_rule_in_effect_status(
@@ -759,7 +762,7 @@ def get_rule_in_effect_status(
         # 112: undetermined (rule is too complicated for current implementation)
     }
     dummy_stdout, dummy_stderr, retval = runner.run(
-        [__exec("crm_rule"), "--check", "--rule", rule_id, "--xml-text", "-"],
+        [settings.crm_rule, "--check", "--rule", rule_id, "--xml-text", "-"],
         stdin_string=cib_xml,
     )
     return translation_map.get(retval, CibRuleInEffectStatus.UNKNOWN)
