@@ -377,7 +377,7 @@ class ValidateOperation(TestCase):
                     report_codes.INVALID_OPTION_VALUE,
                     option_value="c",
                     option_name="record-pending",
-                    allowed_values=["0", "1", "true", "false"],
+                    allowed_values="a pacemaker boolean value: '0', '1', 'false', 'n', 'no', 'off', 'on', 'true', 'y', 'yes'",
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
@@ -385,7 +385,7 @@ class ValidateOperation(TestCase):
                     report_codes.INVALID_OPTION_VALUE,
                     option_value="d",
                     option_name="enabled",
-                    allowed_values=["0", "1", "true", "false"],
+                    allowed_values="a pacemaker boolean value: '0', '1', 'false', 'n', 'no', 'off', 'on', 'true', 'y', 'yes'",
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
