@@ -1,24 +1,26 @@
 from functools import partial
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
+
 from lxml import etree
 
+from pcs.common.reports import codes as report_codes
+from pcs.common.tools import Version
+from pcs.lib.env import LibraryEnvironment
+
 from pcs_test.tools import fixture
 from pcs_test.tools.assertions import assert_xml_equal
 from pcs_test.tools.command_env import get_env_tools
 from pcs_test.tools.custom_mock import (
-    TmpFileMock,
     TmpFileCall,
+    TmpFileMock,
 )
-from pcs_test.tools.misc import (
-    get_test_resource as rc,
-    create_setup_patch_mixin,
-)
+from pcs_test.tools.misc import create_setup_patch_mixin
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.xml import etree_to_str
 
-from pcs.common.reports import codes as report_codes
-from pcs.common.tools import Version
-from pcs.lib.env import LibraryEnvironment
-
 
 def mock_tmpfile(filename):
     mock_file = mock.MagicMock()
@@ -428,7 +430,7 @@ class PushCibMockedWithWait(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
 
-    def test_wait_not_suported_for_mocked_cib(self):
+    def test_wait_not_supported_for_mocked_cib(self):
         tmp_file = "/fake/tmp/file"
         (
             self.config.env.set_cib_data(
