@@ -1,10 +1,14 @@
 # pylint: disable=line-too-long
+import re
 from textwrap import dedent
 from unittest import TestCase
 
+from pcs import settings
+
 from pcs_test.tools.assertions import AssertPcsMixin
+from pcs_test.tools.bin_mock import get_mock_settings
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.misc import (
-    get_test_resource as rc,
     get_tmp_file,
     is_minimum_pacemaker_version,
     is_pacemaker_21_without_20_compatibility,
@@ -34,13 +38,22 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
                 "stonith create Sa fence_apc ip=i username=u action=reboot "
                 "--force"
             ).split(),
-            "Warning: stonith option 'action' is deprecated and should not be"
-            " used, use 'pcmk_off_action', 'pcmk_reboot_action' instead\n",
+            stderr_start=(
+                "Warning: stonith option 'action' is deprecated and should not be "
+                "used, use 'pcmk_off_action', 'pcmk_reboot_action' instead\n"
+            ),
         )
 
     def fixture_stonith_cycle(self):
-        self.assert_pcs_success(
-            "stonith create Sc fence_ipmilan method=cycle".split()
+        self.assert_pcs_success_ignore_output(
+            (
+                "stonith",
+                "create",
+                "Sc",
+                "fence_ipmilan",
+                "method=cycle",
+                "--force",
+            )
         )
 
     def fixture_resource(self):
@@ -49,9 +62,11 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
                 "resource create dummy ocf:pacemaker:Dummy action=reboot "
                 "method=cycle --force"
             ).split(),
-            "Warning: invalid resource options: 'action', 'method', allowed "
-            "options are: 'envfile', 'fail_start_on', 'fake', 'op_sleep', "
-            "'passwd', 'state', 'trace_file', 'trace_ra'\n",
+            stderr_full=(
+                "Warning: invalid resource options: 'action', 'method', allowed "
+                "options are: 'envfile', 'fail_start_on', 'fake', 'op_sleep', "
+                "'passwd', 'state', 'trace_file', 'trace_ra'\n"
+            ),
         )
 
     def test_warning_stonith_action(self):
@@ -191,6 +206,39 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
                 ),
             )
 
+    def test_no_stonith_warning_when_stonith_in_group(self):
+        self.assert_pcs_success(
+            "stonith create S fence_xvm --group G".split(),
+            stderr_full=(
+                "Deprecation Warning: Option to group stonith resource is "
+                "deprecated and will be removed in a future release.\n"
+            ),
+        )
+        self.pcs_runner.corosync_conf_opt = self.corosync_conf
+        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_binary")
+        if PCMK_2_0_3_PLUS:
+            self.assert_pcs_success(
+                ["status"],
+                stdout_start=dedent(
+                    """\
+                    Cluster name: test99
+                    Cluster Summary:
+                """
+                ),
+            )
+        else:
+            self.assert_pcs_success(
+                ["status"],
+                stdout_start=dedent(
+                    """\
+                    Cluster name: test99
+
+                    Stack: unknown
+                    Current DC: NONE
+                """
+                ),
+            )
+
     def test_disabled_stonith_does_not_care_about_missing_devices(self):
         self.assert_pcs_success("property set stonith-enabled=false".split())
         self.pcs_runner.corosync_conf_opt = self.corosync_conf
@@ -242,31 +290,31 @@ class ResourceStonithStatusBase(AssertPcsMixin):
     def test_not_resource_or_tag_id(self):
         self.assert_pcs_fail(
             self.command + ["cx1"],
-            stdout_full="Error: resource or tag id 'cx1' not found\n",
+            "Error: resource or tag id 'cx1' not found\n",
         )
 
     def test_nonexistent_id(self):
         self.assert_pcs_fail(
             self.command + ["nonexistent"],
-            stdout_full="Error: resource or tag id 'nonexistent' not found\n",
+            "Error: resource or tag id 'nonexistent' not found\n",
         )
 
     def test_missing_node_value(self):
         self.assert_pcs_fail(
             self.command + ["node="],
-            stdout_full="Error: missing value of 'node' option\n",
+            "Error: missing value of 'node' option\n",
         )
 
     def test_missing_node_key(self):
         self.assert_pcs_fail(
             self.command + ["=node"],
-            stdout_full="Error: missing key in '=node' option\n",
+            "Error: missing key in '=node' option\n",
         )
 
     def test_more_node_options(self):
         self.assert_pcs_fail(
             self.command + ["node=rh-1", "node=rh-2"],
-            stdout_full=(
+            (
                 "Error: duplicate option 'node' with different values 'rh-1' "
                 "and 'rh-2'\n"
             ),
@@ -275,7 +323,7 @@ class ResourceStonithStatusBase(AssertPcsMixin):
     def test_more_no_node_option(self):
         self.assert_pcs_fail(
             self.command + ["r1", "r2"],
-            stdout_full="Error: missing value of 'r2' option\n",
+            "Error: missing value of 'r2' option\n",
         )
 
     def test_resource_id(self):
@@ -525,6 +573,8 @@ class StonithStatus(ResourceStonithStatusBase, TestCase):
           * fence-rh-1	(stonith:fence_xvm):	 Started rh-1
           * fence-rh-2	(stonith:fence_xvm):	 Stopped
           * fence-kdump	(stonith:fence_kdump):	 Stopped
+
+        Fencing Levels:
          Target: rh-1
            Level 1 - fence-kdump
            Level 2 - fence-rh-1
@@ -536,6 +586,8 @@ class StonithStatus(ResourceStonithStatusBase, TestCase):
     active_resources_output = outdent(
         """\
           * fence-rh-1	(stonith:fence_xvm):	 Started rh-1
+
+        Fencing Levels:
          Target: rh-1
            Level 1 - fence-kdump
            Level 2 - fence-rh-1
@@ -657,3 +709,36 @@ class StatusResources(ResourceStonithStatusBase, TestCase):
         self.assert_pcs_success(
             ["status", "--hide-inactive"], stdout_start=self.no_resources_status
         )
+
+
+class XmlStatus(AssertPcsMixin, TestCase):
+    def setUp(self):
+        self.temp_cib = get_tmp_file("tier1_status_xml_status")
+        write_file_to_tmpfile(rc("cib-empty.xml"), self.temp_cib)
+        self.pcs_runner = PcsRunner(self.temp_cib.name)
+
+    def tearDown(self):
+        self.temp_cib.close()
+
+    def test_success(self):
+        xml = r"""
+            <pacemaker-result api-version="[^"]*" request="{crm_mon} --one-shot --inactive --output-as xml">
+              <summary>
+                <stack type="unknown"/>
+                <current_dc present="false"/>
+                <last_update time="[^"]*"/>
+                <last_change time="Thu Aug 23 16:49:17 2012" user="" client="crmd" origin="rh7-3"/>
+                <nodes_configured number="0"/>
+                <resources_configured number="0" disabled="0" blocked="0"/>
+                <cluster_options[^/>]*/>
+              </summary>
+              <nodes/>
+              <status code="0" message="OK"/>
+            </pacemaker-result>
+        """.format(
+            crm_mon=settings.crm_mon
+        )
+        self.assert_pcs_success(
+            ["status", "xml"],
+            stdout_regexp=re.compile(dedent(xml).strip(), re.MULTILINE),
+        )
