@@ -85,11 +85,11 @@ class TagCreate(TestTagMixin, TestCase):
     def test_create_not_enough_arguments(self):
         self.assert_pcs_fail(
             "tag create".split(),
-            stdout_start="\nUsage: pcs tag <command>",
+            stderr_start="\nUsage: pcs tag <command>",
         )
         self.assert_pcs_fail(
             "tag create tag".split(),
-            stdout_start="\nUsage: pcs tag <command>",
+            stderr_start="\nUsage: pcs tag <command>",
         )
         self.assert_resources_xml_in_cib(self.fixture_tags_xml())
 
@@ -174,12 +174,12 @@ class TagConfigListBase(TestTagMixin):
 
         self.assert_pcs_success(
             ["tag"],
-            " No tags defined\n",
+            stderr_full=" No tags defined\n",
         )
 
         self.assert_pcs_success(
             ["tag", self.command],
-            self.deprecation_msg + " No tags defined\n",
+            stderr_full=(self.deprecation_msg + " No tags defined\n"),
         )
 
     def test_config_tag_does_not_exist(self):
@@ -197,8 +197,7 @@ class TagConfigListBase(TestTagMixin):
     def test_config_tags_defined(self):
         self.assert_pcs_success(
             ["tag", self.command],
-            self.deprecation_msg
-            + dedent(
+            dedent(
                 """\
                 tag1
                   x1
@@ -216,13 +215,13 @@ class TagConfigListBase(TestTagMixin):
                   x3
                 """
             ),
+            stderr_full=self.deprecation_msg,
         )
 
     def test_config_specified_tags(self):
         self.assert_pcs_success(
             ["tag", self.command, "tag2", "tag1"],
-            self.deprecation_msg
-            + dedent(
+            dedent(
                 """\
                 tag2
                   y1
@@ -233,6 +232,7 @@ class TagConfigListBase(TestTagMixin):
                   x3
                 """
             ),
+            stderr_full=self.deprecation_msg,
         )
 
 
@@ -260,41 +260,14 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
         Cluster Name: test99
         Corosync Nodes:
          rh7-1 rh7-2
-        {pacemaker_nodes}
-        {resources}
-        {stonith_devices}{fencing_levels}{constraints}
-        Alerts:
-         No alerts defined
-
-        Resources Defaults:
-          No defaults set
-        Operations Defaults:
-          No defaults set
-
-        Cluster Properties:
-        {tags}
-        Quorum:
-          Options:
-        """
-    )
-    empty_pacemaker_nodes = "Pacemaker Nodes:"
-    empty_resources = "\nResources:\n"
-    empty_stonith_devices = "Stonith Devices:\n"
-    empty_fencing_levels = "Fencing Levels:\n"
-    empty_constraints = outdent(
-        """
-        Location Constraints:
-        Ordering Constraints:
-        Colocation Constraints:
-        Ticket Constraints:
-        """
-    )
-    empty_tags = outdent(
-        """
-        Tags:
-         No tags defined
-        """
+        {pacemaker_nodes}{resources}{stonith_devices}{fencing_levels}{constraints}{tags}"""
     )
+    empty_pacemaker_nodes = "Pacemaker Nodes:\n"
+    empty_resources = ""
+    empty_stonith_devices = ""
+    empty_fencing_levels = ""
+    empty_constraints = ""
+    empty_tags = ""
     expected_pacemaker_nodes = outdent(
         """\
         Pacemaker Nodes:
@@ -302,44 +275,37 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
         """
     )
     expected_resources = outdent(
-        # pylint: disable=line-too-long
-        """\
+        """
         Resources:
           Resource: not-in-tags (class=ocf provider=pacemaker type=Dummy)
             Operations:
               monitor: not-in-tags-monitor-interval-10s
-                interval=10s
-                timeout=20s
+                interval=10s timeout=20s
           Resource: x1 (class=ocf provider=pacemaker type=Dummy)
             Operations:
               monitor: x1-monitor-interval-10s
-                interval=10s
-                timeout=20s
+                interval=10s timeout=20s
           Resource: x2 (class=ocf provider=pacemaker type=Dummy)
             Operations:
               monitor: x2-monitor-interval-10s
-                interval=10s
-                timeout=20s
+                interval=10s timeout=20s
           Resource: x3 (class=ocf provider=pacemaker type=Dummy)
             Operations:
               monitor: x3-monitor-interval-10s
-                interval=10s
-                timeout=20s
+                interval=10s timeout=20s
           Resource: y1 (class=ocf provider=pacemaker type=Dummy)
             Operations:
               monitor: y1-monitor-interval-10s
-                interval=10s
-                timeout=20s
+                interval=10s timeout=20s
           Clone: y2-clone
             Resource: y2 (class=ocf provider=pacemaker type=Dummy)
               Operations:
                 monitor: y2-monitor-interval-10s
-                  interval=10s
-                  timeout=20s
+                  interval=10s timeout=20s
         """
     )
     expected_stonith_devices = outdent(
-        """\
+        """
         Stonith Devices:
           Resource: fence-rh-1 (class=stonith type=fence_xvm)
             Operations:
@@ -358,7 +324,7 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
         """
     )
     expected_fencing_levels = outdent(
-        """\
+        """
         Fencing Levels:
           Target: rh-1
             Level 1 - fence-kdump
@@ -390,15 +356,8 @@ class PcsConfigTagsTest(TestTagMixin, TestCase):
     expected_constraints = outdent(
         """
         Location Constraints:
-          Resource: x1
-            Enabled on:
-              Node: rh7-1 (score:INFINITY) (id:cx1)
-          Resource: x2
-            Enabled on:
-              Node: rh7-1 (score:INFINITY) (id:cx2)
-        Ordering Constraints:
-        Colocation Constraints:
-        Ticket Constraints:
+          resource 'x1' prefers node 'rh7-1' with score INFINITY (id: cx1)
+          resource 'x2' prefers node 'rh7-1' with score INFINITY (id: cx2)
         """
     )
 
@@ -454,7 +413,7 @@ class TagRemoveDeleteBase(TestTagMixin):
     def test_remove_not_enough_arguments(self):
         self.assert_pcs_fail(
             ["tag", self.command],
-            stdout_start="\nUsage: pcs tag <command>",
+            stderr_start="\nUsage: pcs tag <command>",
         )
         self.assert_resources_xml_in_cib(self.fixture_tags_xml())
 
@@ -523,7 +482,7 @@ class ResourceRemoveDeleteBase(TestTagMixin):
     def test_resource_not_referenced_in_tags(self):
         self.assert_pcs_success(
             ["resource", self.command, "not-in-tags"],
-            "Deleting Resource - not-in-tags\n",
+            stderr_full="Deleting Resource - not-in-tags\n",
         )
         self.assert_resources_xml_in_cib(self.fixture_tags_xml())
 
@@ -601,14 +560,14 @@ class TagUpdate(TestTagMixin, TestCase):
     def test_fail_not_enough_arguments(self):
         self.assert_pcs_fail(
             "tag update".split(),
-            stdout_start="\nUsage: pcs tag <command>",
+            stderr_start="\nUsage: pcs tag <command>",
         )
         self.assert_resources_xml_in_cib(self.fixture_tags_xml())
 
     def test_fail_tag_update_ids_not_specified(self):
         self.assert_pcs_fail(
             "tag update tag1".split(),
-            stdout_start=(
+            stderr_start=(
                 "Hint: Specify at least one id for 'add' or 'remove' arguments."
             ),
         )
@@ -617,7 +576,7 @@ class TagUpdate(TestTagMixin, TestCase):
     def test_fail_tag_update_add_ids_not_specified(self):
         self.assert_pcs_fail(
             "tag update tag1 add".split(),
-            stdout_start=(
+            stderr_start=(
                 "Hint: Specify at least one id for 'add' or 'remove' arguments."
             ),
         )
@@ -626,7 +585,7 @@ class TagUpdate(TestTagMixin, TestCase):
     def test_fail_tag_update_remove_ids_not_specified(self):
         self.assert_pcs_fail(
             "tag update tag1 remove".split(),
-            stdout_start=(
+            stderr_start=(
                 "Hint: Specify at least one id for 'add' or 'remove' arguments."
             ),
         )
