@@ -8,7 +8,7 @@ from lxml.etree import LXML_VERSION
 from pcs.common import reports
 from pcs.lib.errors import LibraryError
 
-# pylint: disable=invalid-name
+from pcs_test.tools.fixture import ReportItemFixture
 
 
 def prepare_diff(first, second):
@@ -21,6 +21,7 @@ def prepare_diff(first, second):
 
 
 def ac(a, b):
+    # pylint: disable=invalid-name
     """
     Compare the actual output 'a' and an expected output 'b', print diff b a
     """
@@ -41,178 +42,6 @@ def start_tag_error_text():
     return msg
 
 
-class AssertPcsMixinOld:
-    """Run pcs command and assert its result"""
-
-    def assert_pcs_success_all(self, command_list):
-        for command in command_list:
-            stdout, pcs_returncode = self.pcs_runner.run(command)
-            if pcs_returncode != 0:
-                raise AssertionError(
-                    (
-                        "Command '{0}' does not succeed.\n"
-                        "return_code: {1}\n"
-                        "stdout:\n{2}"
-                    ).format(command, pcs_returncode, stdout)
-                )
-
-    def assert_pcs_success(
-        self,
-        command,
-        stdout_full=None,
-        stdout_start=None,
-        stdout_regexp=None,
-        despace=False,
-    ):
-        full = stdout_full
-        if (
-            stdout_start is None
-            and stdout_full is None
-            and stdout_regexp is None
-        ):
-            full = ""
-        self.assert_pcs_result(
-            command,
-            stdout_full=full,
-            stdout_start=stdout_start,
-            stdout_regexp=stdout_regexp,
-            returncode=0,
-            despace=despace,
-        )
-
-    def assert_pcs_fail(
-        self, command, stdout_full=None, stdout_start=None, stdout_regexp=None
-    ):
-        self.assert_pcs_result(
-            command,
-            stdout_full=stdout_full,
-            stdout_start=stdout_start,
-            stdout_regexp=stdout_regexp,
-            returncode=1,
-        )
-
-    def assert_pcs_fail_regardless_of_force(
-        self, command, stdout_full=None, stdout_start=None, stdout_regexp=None
-    ):
-        self.assert_pcs_fail(command, stdout_full, stdout_start, stdout_regexp)
-        self.assert_pcs_fail(
-            command + ["--force"], stdout_full, stdout_start, stdout_regexp
-        )
-
-    def assert_pcs_result(
-        self,
-        command,
-        stdout_full=None,
-        stdout_start=None,
-        stdout_regexp=None,
-        returncode=0,
-        despace=False,
-    ):
-        msg = (
-            "Please specify exactly one: stdout_start or stdout_full or"
-            " stdout_regexp"
-        )
-        specified_stdout = [
-            stdout
-            for stdout in (stdout_full, stdout_start, stdout_regexp)
-            if stdout is not None
-        ]
-        if not specified_stdout:
-            raise Exception(msg + ", none specified")
-        if len(specified_stdout) > 1:
-            raise Exception(msg + ", both specified")
-
-        stdout = self.assert_pcs_success_ignore_output(command, returncode)
-        message_template = (
-            "{reason}\ncommand: {cmd}\ndiff is (expected is 2nd):\n{diff}"
-            + "\nFull stdout:\n{stdout}"
-        )
-        if stdout_start:
-            expected_start = self.__prepare_output(stdout_start)
-            if not stdout.startswith(expected_start):
-                self.fail(
-                    message_template.format(
-                        reason="Stdout does not start as expected",
-                        cmd=command,
-                        diff=prepare_diff(
-                            stdout[: len(expected_start)], expected_start
-                        ),
-                        stdout=stdout,
-                    )
-                )
-        elif stdout_regexp:
-            if not isinstance(stdout_regexp, re.Pattern):
-                stdout_regexp = re.compile(stdout_regexp)
-            if not stdout_regexp.search(stdout):
-                self.fail(
-                    (
-                        "Stdout does not match the expected regexp\n"
-                        "command: {cmd}\nregexp:\n{regexp} (flags: {flags})\n"
-                        "\nFull stdout:\n{stdout}"
-                    ).format(
-                        cmd=command,
-                        regexp=stdout_regexp.pattern,
-                        flags=", ".join(
-                            self.__prepare_regexp_flags(stdout_regexp.flags)
-                        ),
-                        stdout=stdout,
-                    )
-                )
-        else:
-            expected_full = self.__prepare_output(stdout_full)
-            if (despace and _despace(stdout) != _despace(expected_full)) or (
-                not despace and stdout != expected_full
-            ):
-                self.assertEqual(
-                    stdout,
-                    expected_full,
-                    message_template.format(
-                        reason="Stdout is not as expected",
-                        cmd=command,
-                        diff=prepare_diff(stdout, expected_full),
-                        stdout=stdout,
-                    ),
-                )
-
-    def assert_pcs_success_ignore_output(self, command, returncode=0):
-        stdout, retval_actual = self.pcs_runner.run(command)
-
-        self.assertEqual(
-            returncode,
-            retval_actual,
-            (
-                f"Expected return code '{returncode}' but was '{retval_actual}'\n"
-                f"** command: {command}\n"
-                f"** stdout:\n{stdout}\n"
-            ),
-        )
-        return stdout
-
-    def __prepare_output(self, output):
-        # pylint: disable=no-self-use
-        return "\n".join(output + [""]) if isinstance(output, list) else output
-
-    def __prepare_regexp_flags(self, flags):
-        # pylint: disable=no-self-use
-        # python2 has different flags than python3
-        possible_flags = [
-            "ASCII",
-            "DEBUG",
-            "IGNORECASE",
-            "LOCALE",
-            "MULTILINE",
-            "DOTALL",
-            "UNICODE",
-            "VERBOSE",
-        ]
-        used_flags = [
-            f
-            for f in possible_flags
-            if hasattr(re, f) and (flags & getattr(re, f))
-        ]
-        return sorted(used_flags)
-
-
 class AssertPcsMixin:
     """Run pcs command and assert its result"""
 
@@ -662,9 +491,9 @@ def assert_report_item_list_equal(
         )
 
 
-def assert_raise_library_error(callableObj, *report_info_list):
+def assert_raise_library_error(callable_obj, *report_info_list):
     try:
-        callableObj()
+        callable_obj()
         raise AssertionError("LibraryError not raised")
     except LibraryError as e:
         assert_report_item_list_equal(e.args, list(report_info_list))
@@ -677,7 +506,9 @@ def __find_report_info(expected_report_info_list, real_report_item):
     return None
 
 
-def __report_item_equal(real_report_item, report_item_info):
+def __report_item_equal(
+    real_report_item: reports.ReportItem, report_item_info: ReportItemFixture
+) -> bool:
     report_dto: reports.ReportItemDto = real_report_item.to_dto()
     return (
         report_dto.severity.level == report_item_info[0]
