@@ -4,7 +4,6 @@ require 'childprocess'
 require 'set'
 require 'timeout'
 require 'rexml/document'
-require 'base64'
 require 'tempfile'
 
 require 'pcs.rb'
@@ -23,7 +22,6 @@ require 'pcsd_exchange_format.rb'
 # Commands for remote access
 def remote(params, request, auth_user)
   remote_cmd_without_pacemaker = {
-      :capabilities => method(:capabilities),
       :status => method(:node_status),
       :cluster_status => method(:cluster_status_remote),
       :get_quorum_info => method(:get_quorum_info),
@@ -53,15 +51,6 @@ def remote(params, request, auth_user)
       :sbd_enable => method(:sbd_enable),
       :remove_stonith_watchdog_timeout=> method(:remove_stonith_watchdog_timeout),
       :set_stonith_watchdog_timeout_to_zero => method(:set_stonith_watchdog_timeout_to_zero),
-      :qdevice_net_get_ca_certificate => method(:qdevice_net_get_ca_certificate),
-      # lib api:
-      # /api/v1/qdevice-qdevice-net-sign-certificate-request/v1
-      :qdevice_net_sign_node_certificate => method(:qdevice_net_sign_node_certificate),
-      :qdevice_net_client_init_certificate_storage => method(:qdevice_net_client_init_certificate_storage),
-      # lib api:
-      # /api/v1/qdevice-client-net-import-certificate/v1
-      :qdevice_net_client_import_certificate => method(:qdevice_net_client_import_certificate),
-      :qdevice_net_client_destroy => method(:qdevice_net_client_destroy),
       :qdevice_client_enable => method(:qdevice_client_enable),
       :qdevice_client_disable => method(:qdevice_client_disable),
       :qdevice_client_start => method(:qdevice_client_start),
@@ -132,8 +121,6 @@ def remote(params, request, auth_user)
       # lib api:
       # /api/v1/stonith-agent-describe-agent/v1
       :get_fence_agent_metadata => method(:get_fence_agent_metadata),
-      :manage_resource => method(:manage_resource),
-      :unmanage_resource => method(:unmanage_resource),
   }
 
   command = params[:command].to_sym
@@ -175,12 +162,6 @@ def _get_param_list(params)
   return param_line + meta_options, flags
 end
 
-def capabilities(params, request, auth_user)
-  return JSON.generate({
-    :pcsd_capabilities => CAPABILITIES_PCSD,
-  })
-end
-
 # provides remote cluster status to a local gui
 def cluster_status_gui(auth_user, cluster_name, dont_update_config=false)
   config = PCSConfig.new(Cfgsync::PcsdSettings.from_file().text())
@@ -1875,89 +1856,6 @@ def set_stonith_watchdog_timeout_to_zero(param, request, auth_user)
   end
 end
 
-def qdevice_net_get_ca_certificate(params, request, auth_user)
-  unless allowed_for_local_cluster(auth_user, Permissions::READ)
-    return 403, 'Permission denied'
-  end
-  begin
-    return [
-      200,
-      Base64.encode64(File.read(COROSYNC_QDEVICE_NET_SERVER_CA_FILE))
-    ]
-  rescue => e
-    return [400, "Unable to read certificate: #{e}"]
-  end
-end
-
-def qdevice_net_sign_node_certificate(params, request, auth_user)
-  unless allowed_for_local_cluster(auth_user, Permissions::READ)
-    return 403, 'Permission denied'
-  end
-  stdout, stderr, retval = run_cmd_options(
-    auth_user,
-    {'stdin' => params[:certificate_request]},
-    PCS, '--name', params[:cluster_name], '--', 'qdevice', 'sign-net-cert-request'
-  )
-  if retval != 0
-    return [400, stderr.join('')]
-  end
-  return [200, stdout.join('')]
-end
-
-def qdevice_net_client_init_certificate_storage(params, request, auth_user)
-  # Last step of adding qdevice into a cluster is distribution of corosync.conf
-  # file with qdevice settings. This requires FULL permissions currently.
-  # If that gets relaxed, we can require lower permissions in here as well.
-  unless allowed_for_local_cluster(auth_user, Permissions::FULL)
-    return 403, 'Permission denied'
-  end
-  stdout, stderr, retval = run_cmd_options(
-    auth_user,
-    {'stdin' => params[:ca_certificate]},
-    PCS, '--', 'qdevice', 'net-client', 'setup'
-  )
-  if retval != 0
-    return [400, stderr.join('')]
-  end
-  return [200, stdout.join('')]
-end
-
-def qdevice_net_client_import_certificate(params, request, auth_user)
-  # Last step of adding qdevice into a cluster is distribution of corosync.conf
-  # file with qdevice settings. This requires FULL permissions currently.
-  # If that gets relaxed, we can require lower permissions in here as well.
-  unless allowed_for_local_cluster(auth_user, Permissions::FULL)
-    return 403, 'Permission denied'
-  end
-  stdout, stderr, retval = run_cmd_options(
-    auth_user,
-    {'stdin' => params[:certificate]},
-    PCS, '--', 'qdevice', 'net-client', 'import-certificate'
-  )
-  if retval != 0
-    return [400, stderr.join('')]
-  end
-  return [200, stdout.join('')]
-end
-
-def qdevice_net_client_destroy(param, request, auth_user)
-  # When removing a qdevice from a cluster, an updated corosync.conf file
-  # with removed qdevice settings is distributed. This requires FULL permissions
-  # currently. If that gets relaxed, we can require lower permissions in here
-  # as well.
-  unless allowed_for_local_cluster(auth_user, Permissions::FULL)
-    return 403, 'Permission denied'
-  end
-  stdout, stderr, retval = run_cmd(
-    auth_user,
-    PCS, '--', 'qdevice', 'net-client', 'destroy'
-  )
-  if retval != 0
-    return [400, stderr.join('')]
-  end
-  return [200, stdout.join('')]
-end
-
 def qdevice_client_disable(param, request, auth_user)
   unless allowed_for_local_cluster(auth_user, Permissions::WRITE)
     return 403, 'Permission denied'
@@ -2006,48 +1904,6 @@ def qdevice_client_start(param, request, auth_user)
   end
 end
 
-def manage_resource(param, request, auth_user)
-  unless allowed_for_local_cluster(auth_user, Permissions::WRITE)
-    return 403, 'Permission denied'
-  end
-  unless param[:resource_list_json]
-    return [400, "Required parameter 'resource_list_json' is missing."]
-  end
-  begin
-    resource_list = JSON.parse(param[:resource_list_json])
-    _, err, retval = run_cmd(
-      auth_user, PCS, '--', 'resource', 'manage', *resource_list
-    )
-    if retval != 0
-      return [400, err.join('')]
-    end
-    return [200, '']
-  rescue JSON::ParserError
-    return [400, 'Invalid input data format']
-  end
-end
-
-def unmanage_resource(param, request, auth_user)
-  unless allowed_for_local_cluster(auth_user, Permissions::WRITE)
-    return 403, 'Permission denied'
-  end
-  unless param[:resource_list_json]
-    return [400, "Required parameter 'resource_list_json' is missing."]
-  end
-  begin
-    resource_list = JSON.parse(param[:resource_list_json])
-    _, err, retval = run_cmd(
-      auth_user, PCS, '--', 'resource', 'unmanage', *resource_list
-    )
-    if retval != 0
-      return [400, err.join('')]
-    end
-    return [200, '']
-  rescue JSON::ParserError
-    return [400, 'Invalid input data format']
-  end
-end
-
 def booth_set_config(params, request, auth_user)
   begin
     check_permissions(auth_user, Permissions::WRITE)
